@@ -18,7 +18,7 @@ class GerritAccountSSHKey(GerritBase):
         self.account = account
         self.gerrit = gerrit
         self.endpoint = f"/accounts/{self.account}/sshkeys"
-        GerritBase.__init__(self)
+        super().__init__(self)
 
     def __str__(self):
         return str(self.seq)
@@ -60,7 +60,7 @@ class GerritAccountSSHKeys:
             seq = result.get("seq")
             return GerritAccountSSHKey(seq=seq, account=self.account, gerrit=self.gerrit)
         except requests.exceptions.HTTPError as error:
-            if error.response.status_code in (404, 400):
+            if error.response.status_code == 404:
                 message = f"SSH key {seq} does not exist"
                 logger.error(message)
                 raise SSHKeyNotFoundError(message)
