@@ -1,18 +1,13 @@
 #!/usr/bin/env python
 # -*- coding:utf-8 -*-
 # @Author: Jialiang Shi
-try:
-    from urllib.parse import quote_plus
-except ImportError:
-    from urllib import quote_plus
-
-from gerrit.utils.models import BaseModel
+from urllib.parse import quote_plus
 
 
-class GerritChangeEdit(BaseModel):
-    def __init__(self, **kwargs):
-        super().__init__(**kwargs)
-        self.entity_name = "ref"
+class GerritChangeEdit:
+    def __init__(self, change: str, gerrit):
+        self.change = change
+        self.gerrit = gerrit
         self.endpoint = f"/changes/{self.change}/edit"
 
     def get_change_file_content(self, file):
@@ -91,8 +86,7 @@ class GerritChangeEdit(BaseModel):
             edit.change_commit_message(input_)
 
         :param input_: the ChangeEditMessageInput entity,
-          https://gerrit-review.googlesource.com/Documentation/rest-api-changes.html
-          #change-edit-message-input
+          https://gerrit-review.googlesource.com/Documentation/rest-api-changes.html#change-edit-message-input
         :return:
         """
         self.gerrit.put(self.endpoint + ":message",
@@ -105,7 +99,7 @@ class GerritChangeEdit(BaseModel):
 
         :return:
         """
-        return self.gerrit.get(self.endpoint + f":message")
+        return self.gerrit.get(self.endpoint + ":message")
 
     def publish(self, input_):
         """
@@ -122,8 +116,7 @@ class GerritChangeEdit(BaseModel):
             edit.publish(input_)
 
         :param input_: the PublishChangeEditInput entity,
-          https://gerrit-review.googlesource.com/Documentation/rest-api-changes.html
-          #publish-change-edit-input
+          https://gerrit-review.googlesource.com/Documentation/rest-api-changes.html#publish-change-edit-input
         :return:
         """
         self.gerrit.post(self.endpoint + ":publish",
