@@ -19,7 +19,7 @@ class GerritChangeReviewer(GerritBase):
         self.change = change
         self.gerrit = gerrit
         self.endpoint = f"/changes/{self.change}/reviewers/{self.account}"
-        GerritBase.__init__(self)
+        super().__init__(self)
 
     def __str__(self):
         return str(self.account)
@@ -117,7 +117,7 @@ class GerritChangeReviewers:
             account = result[0].get("_account_id")
             return GerritChangeReviewer(account=account, change=self.change, gerrit=self.gerrit)
         except requests.exceptions.HTTPError as error:
-            if error.response.status_code in (404, 400):
+            if error.response.status_code == 404:
                 message = f"Reviewer {account} does not exist"
                 logger.error(message)
                 raise ReviewerNotFoundError(message)
